@@ -210,11 +210,14 @@ class Changelog(object):
                     self.unreleased.change_blocks[change_type].changes.append(change)
         return self
 
-    def difference(self, other: "Changelog") -> VersionCollection:
+    def difference(self, other: "Changelog", revert: bool = False) -> VersionCollection:
         res = VersionCollection()
 
-        for version in other.versions:
-            if version not in self.versions:
+        this_changelog = other if revert else self
+        other_changelog = self if revert else other
+
+        for version in other_changelog.versions:
+            if version not in this_changelog.versions:
                 res.append(version)
 
         unreleased = VersionBlock(version="unreleased")
@@ -224,14 +227,15 @@ class Changelog(object):
                 for change_block in released_version.change_blocks:
                     released_version_diff.extend(released_version.change_blocks[change_block].changes)
 
-            for change_type in other.unreleased.change_blocks:
-                if change_type not in self.unreleased.change_blocks:
-                    unreleased.change_blocks[change_type] = other.unreleased.change_blocks[change_type]
-                    continue
-                for change in other.unreleased.change_blocks[change_type].changes:
-                    if change not in self.unreleased.change_blocks[change_type].changes:
-                        if change_type not in unreleased.change_blocks:
-                            unreleased.change_blocks[change_type] = ChangeBlock(change_type=change_type)
-                        unreleased.change_blocks[change_type].changes.append(change)
+            if other_changelog.unreleased:
+                for change_type in other_changelog.unreleased.change_blocks:
+                    if change_type not in this_changelog.unreleased.change_blocks:
+                        unreleased.change_blocks[change_type] = other_changelog.unreleased.change_blocks[change_type]
+                        continue
+                    for change in other_changelog.unreleased.change_blocks[change_type].changes:
+                        if change not in this_changelog.unreleased.change_blocks[change_type].changes:
+                            if change_type not in unreleased.change_blocks:
+                                unreleased.change_blocks[change_type] = ChangeBlock(change_type=change_type)
+                            unreleased.change_blocks[change_type].changes.append(change)
             res.append(unreleased)
         return res
